# https://fedoraproject.org/wiki/Packaging:Haskell

%global pkg_name async

%bcond_with tests

Name:           ghc-%{pkg_name}
# part of Haskell Platform
Version:        2.0.1.5
Release:        1%{?dist}
Summary:        Run IO operations asynchronously and wait for their results

License:        BSD
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
# Begin cabal-rpm deps:
BuildRequires:  ghc-stm-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
%endif
# End cabal-rpm deps

%description
This package provides a higher-level interface over threads, in which an
"Async a" is a concurrent thread that will eventually deliver a value of
type "a". The package provides ways to create "Async" computations,
wait for their results, and cancel them.

Using Async is safer than using threads in two ways:

* When waiting for a thread to return a result, if the thread dies with an
exception then the caller must either re-throw the exception ('wait') or handle
it ('waitCatch'); the exception cannot be ignored.

* The API makes it possible to build a tree of threads that are automatically
killed when their parent dies (see 'withAsync').


%package devel
Summary:        Haskell %{pkg_name} library development files
Provides:       %{name}-static = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
This package provides the Haskell %{pkg_name} library development files.


%prep
%setup -q -n %{pkg_name}-%{version}


%build
%ghc_lib_build


%install
%ghc_lib_install


%check
%if %{with tests}
%cabal test
%endif


%post devel
%ghc_pkg_recache


%postun devel
%ghc_pkg_recache


%files -f %{name}.files
%doc LICENSE


%files devel -f %{name}-devel.files


%changelog
* Fri Aug  8 2014 Jens Petersen <petersen@redhat.com> - 2.0.1.5-1
- update to 2.0.1.5

* Tue Jul  8 2014 Jens Petersen <petersen@redhat.com> - 2.0.1.4-31
- f21 rebuild

* Tue Feb  4 2014 Jens Petersen <petersen@redhat.com> - 2.0.1.4-30
- bump release over current haskell-platform

* Thu Nov 28 2013 Jens Petersen <petersen@redhat.com> - 2.0.1.4-27
- separate source package from haskell-platform

* Thu Nov 28 2013 Fedora Haskell SIG <haskell@lists.fedoraproject.org> - 2.0.1.4
- spec file generated by cabal-rpm-0.8.7
